restish.app — Restish v0.7.1 documentation

### Navigation

- index
- modules |
- Restish v0.7.1 documentation »

Overview

# restish.app

Core wsgi application

class `restish.app.` `RestishApp`(root_resource)

  Bases: `object`

  `get_response`(request, resource)

    Recursively call the resource until we get a response.

    A resource is allowed to return another resource to be used in its place. This method handles the recursive calling.

  `locate_resource`(request)
    Locate the resource at the path in request URL by traversing the resource hierarchy.

### Navigation

- index
- modules |
- Restish v0.7.1 documentation »